# gb-dl
A python based utility to download courses from infosec4tc.teachable.com ,ehacking.net ,stackskills.com and designerup.co ...etc for personal offline use.



## Usage
To use this script:
```
open terminal or cmd and run gb-dl.py
Enter course url , email and password when prompted. OR
run gb-dl -f FILE to load multiple course urls from files
run gb-dl -h for help
```
## Installation
``` 
pip install gb-dl

Then get your key here : https://bmc.xyz/l/gbdl 
N.B key will be sent to your email.
 
```

## Version
``` 1.7.2```

## Issues
Report all issues here in github
    

Tested on ubuntu 16 , 18 LTS , Windows 10

## Example of course url:
```
https://stackskills.com/courses/enrolled/68582

```
## Change Log:
```
 Download only a specified section of the course
 Download only specified range of sections
 Show course info without downloading
 Added cookie authentication 
 Downloading multiple courses from a file
 Load cookie from a text file
 Store cookie for future use
 Auto load/detect stored cookie
 Auto load cookie from browser (firefox)
 
   
```

## Support
 Support future development
<br>
<a href="https://www.buymeacoffee.com/barakagb" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" style="height: 12px !important;width: 56px !important;" ></a>

